@@ -6,7 +6,7 @@
 #
 # Authors: Côme BERNIGAUD
 #
-#  This program is free software; 
+#  This program is free software;
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
 #  the Free Software Foundation; either version 2 of the License, or
@@ -50,7 +50,7 @@ sub new {
     }
 
     my $handle;
-    if (!open $handle, '<', $file) {
+    if (!open $handle, q{<}, $file) {
         die "Config: Failed to open $file: $ERRNO";
     }
 
